@@ -1,4 +1,13 @@
 """Implementation of common cast conversion.
+
+Mainly following interfaces are defined.
+
+- to_int_from_float
+    Convert float value to int.
+- to_float_from_int
+    Convert int value to float.
+- to_bool_from_int
+    Convert int value to bool.
 """
 
 
@@ -53,3 +62,29 @@ def to_float_from_int(int_or_float: Union[int, float, Any]) -> Any:
     if not isinstance(int_or_float, int):
         return int_or_float
     return float(int_or_float)
+
+
+def to_bool_from_int(integer: Union[int, Any]) -> bool:
+    """
+    Convert int value to bool.
+
+    Parameters
+    ----------
+    integer : int or Int
+        Integer value to convert.
+
+    Returns
+    -------
+    bool_val : bool
+        Converted boolean value.
+
+    Raises
+    ------
+    ValueError
+        If argument value isn't zero or one.
+    """
+    from apyscript.validation import number_validation
+    number_validation.validate_int_is_zero_or_one(integer=integer)
+    if integer == 0:
+        return False
+    return True
